## $Id: student.py 9502 2012-11-02 06:13:11Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Container for the various objects owned by students.
"""
import grok
from zope.interface import implementedBy
from waeup.kofa.utils.helpers import attrs_to_fields
from waeup.kofa.students.student import StudentFactory
from waeup.kofa.students.interfaces import IStudentNavigation
from kofacustom.nigeria.students.student import NigeriaStudent
from waeup.aaue.students.interfaces import ICustomStudent


class CustomStudent(NigeriaStudent):
    """This is a student container for the various objects
    owned by students.
    """
    grok.implements(ICustomStudent, IStudentNavigation)
    grok.provides(ICustomStudent)

    def getPaymentTuples(self):
        """Special AAUE method needed for selecting courses in semesters
        the student has paid for.
        """
        payments = [(p.p_session, p.p_category, p.p_state)
            for p in self['payments'].values()]
        return payments

# Set all attributes of Student required in IStudent as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
CustomStudent = attrs_to_fields(CustomStudent)

class CustomStudentFactory(StudentFactory):
    """A factory for students.
    """

    def __call__(self, *args, **kw):
        return CustomStudent()

    def getInterfaces(self):
        return implementedBy(CustomStudent)